Main API
========

The primary interface.

.. nice-toc::

   const
      Constants used throughout Yuio.

   io
      Interacting with users.

   parse
      Parsing user input.

   app
      Building CLI applications.

   config
      Working with configs.

   exec
      Executing sub-processes.

   git
      Querying GIT status.

   secret
      Working with sensitive data.

   dbg
      Automated environment collection for bug reports.

   sphinx_ext
      Documenting configs in Sphinx.
